# document.py

# noinspection PyUnresolvedReferences
from live_api.endpoints import *
# noinspection PyUnresolvedReferences
from live_api.service import *

from live_api.base import document

class Documentation:
    """"""
# end Documentation

document(Documentation)